History
=======

2.5.6.2 (2015-05-17)
++++++++++++++++++

- Fix setup.py

2.5.6 (2015-05-17)
++++++++++++++++++

- Synchronize version number with `paranoid-auto-spacing <https://github.com/vinta/paranoid-auto-spacing>`_
- Improve Paranoid Text Spacing algorithm

1.0.0 (2014-02-12)
++++++++++++++++++

- Hello World
